@@ -27,15 +27,6 @@ def pytest_runtest_makereport(item, call):
     if os.environ.get("GITHUB_ACTIONS") != "true":
         return
 
-    try:
-        # If we have the pytest_rerunfailures plugin, and there are still
-        # retries to be run, then ignore error
-        import pytest_rerunfailures
-        if item.execution_count <= pytest_rerunfailures.get_reruns_count(item):
-            return
-    except ImportError:
-        pass
-
     if report.when == "call" and report.failed:
         # collect information to be annotated
         filesystempath, lineno, _ = report.location
@@ -58,19 +49,22 @@ def pytest_runtest_makereport(item, call):
             if not rel_path.startswith(".."):
                 filesystempath = rel_path
 
-        # 0-index to 1-index
-        lineno += 1
+        if lineno is not None:
+            # 0-index to 1-index
+            lineno += 1
 
         # get the name of the current failed test, with parametrize info
         longrepr = report.head_line or item.name
 
         # get the error message and line number from the actual error
-        try:
+        if hasattr(report.longrepr, "reprcrash"):
             longrepr += "\n\n" + report.longrepr.reprcrash.message
             lineno = report.longrepr.reprcrash.lineno
-
-        except AttributeError:
-            pass
+        elif isinstance(report.longrepr, tuple):
+            _, lineno, message = report.longrepr
+            longrepr += "\n\n" + message
+        elif isinstance(report.longrepr, str):
+            longrepr += "\n\n" + report.longrepr
 
         print(
             _error_workflow_command(filesystempath, lineno, longrepr), file=sys.stderr
